import pytest

from tests.utils.ent_mocker import EntitiesMocker
from . import utils


@pytest.fixture()
def mocked_submission(ent_mocker: EntitiesMocker, rest_service):
    submission = ent_mocker.create_submission()
    rest_service.submissions.write_entity(submission)
    ent_mocker.create_submission_storage(submission=submission)
    return submission


def expected(fpath):
    return f'This is a test file: {fpath}'


def test_submission_sources_are_available(client, mocked_submission):
    s = mocked_submission
    response = utils.make_request(client, f'/submissions/{s.id}/files/sources?path=src/main.c')
    assert response.status_code == 200
    assert response.data
    assert response.data.decode('utf-8') == expected('src/main.c')


def test_submission_results_are_available(client, mocked_submission):
    s = mocked_submission
    response = utils.make_request(client, f'/submissions/{s.id}/files/results?path=student.json')
    assert response.status_code == 200
    assert response.data
    assert response.data.decode('utf-8') == expected('student.json')

